#sh
#
# (uncomment the next line to run in debug mode)
# set -x
#
#ipssendcheck ()
# check to see if ipssend exists & is executable
if [ ! -f ipssend ] || [ ! -x ipssend ]
then
  echo "\nThe file \"ipssend\" could not be found or is not executable."
  echo "Please verify that ipssend is located in the same directory"
  echo "as this dumplog file and permissions are set using the"
  echo "\"chmod\" command.  Contact your system administrator."
  exit 1
fi

#numcardscheck ()
# check number of adapters found
numcards=`./ipssend getstatus 0 | grep Found | cut -c7`
if [ "$numcards" -eq 0 ]
then
  echo "\n\"ipssend\" could not detect a Serveraid controller."
  echo "Check to make sure a Serveraid controller is installed."
  exit 1
fi 

clear
echo "\nServeraid Dumplog Script for SCO Unixware, ver 3.0"
echo "Found $numcards Serveraid controller(s)"

#getmodeltype ()
echo "\nPlease enter the model-type of this machine"
echo "(example:  86874RY) -> \c"
read modeltype

#getserialnum ()
echo "\nPlease enter the serial number of this machine"
echo "(example:  12h3456) -> \c"
read serialnum


# check the operating system & version
opsys=`uname -v`
osver=`uname -v | cut -c1`
case $osver
in
  5) opsys="SCO OpenServer $opsys"
     ;;
  7) opsys="SCO Unixware $opsys"
     ;;
  *) opsys="Not a supported SCO operating system"
     ;;
esac

#
# START THE LOOP, CREATE NEW FILENAME FOR EACH ADAPTER FOUND
#
date=`date`
count=1

until [ "$count" -gt "$numcards" ] 
do
filename="$serialnum-sr$count.txt"

echo "\nCollecting all Serveraid logs for adapter $count"
echo "Data for adapter $count will be stored in  $filename"

echo "Serveraid Dumplog Script for SCO Unixware, v3.0\n" >> $filename
echo "Today's date           : $date" >> $filename
echo "Model Type             : $modeltype" >> $filename
echo "Serial Number          : $serialnum" >> $filename
echo "Operating system       : $opsys" >> $filename
echo "Number of Serveraid adapters found in this machine: $numcards" >> $filename
echo "This log is for adapter $count" >> $filename

# BEGIN DUMPING

echo "\n************************************" >> $filename 
echo   "***IPSSEND GETVERSION***************" >> $filename
echo   "************************************" >> $filename
./ipssend getversion >> $filename

echo "\n************************************" >> $filename
echo   "***IPSSEND CONFIG AL LOG************" >> $filename
echo   "************************************" >> $filename
./ipssend getconfig $count al >> $filename

echo "\n************************************" >> $filename
echo   "***IPSSEND GETBST BAD STRIPE TABLE**" >> $filename
echo   "************************************" >> $filename
./ipssend getbst $count >> $filename

echo "\n************************************" >> $filename
echo   "***IPSSEND GETEVENT DEVICE LOG******" >> $filename
echo   "************************************" >> $filename
./ipssend getevent $count all >> $filename

count=`expr $count + 1`

done   #end of loop

echo "\nCollection of Serveraid Logs Complete."
exit 0

